# OctoprintEnvironmentRequest


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**os** | [**OctoprintPlatformRequest**](OctoprintPlatformRequest.md) |  | 
**python** | [**OctoprintPythonRequest**](OctoprintPythonRequest.md) |  | 
**hardware** | [**OctoprintHardwareRequest**](OctoprintHardwareRequest.md) |  | 
**pi_support** | [**OctoprintPiSupportRequest**](OctoprintPiSupportRequest.md) |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


